@@ -3,9 +3,6 @@ use warnings;
 use strict;
 use base 'Module::CPANTS::Generator';
 
-use vars qw($VERSION);
-$VERSION = "0.26";
-
 
 ##################################################################
 # Analyse
@@ -24,30 +21,31 @@ sub analyse {
 
     my @modules_basedir=grep {/^[^\/]+\.pm$/} @$files;
     $cpants->{metric}{modules_in_basedir}=scalar @modules_basedir;
+    
     if (@modules_basedir) {
-#	$cpants->{metric}{modules_raw}{list_basedir}=\@modules_basedir;
-	push(@module_files,@modules_basedir);
-	$cpants->distnameinfo->dist=~/^(.*)-\w+/i;
-	my $module_name=$1 || "UNKNOWN";
-	$module_name=~s/-/::/g;
-	foreach (@modules_basedir) {
-	    s/\.pm$//;
-	    push(@modules,$module_name."::".$_);
-	}
+        #$cpants->{metric}{modules_raw}{list_basedir}=\@modules_basedir;
+        push(@module_files,@modules_basedir);
+        $cpants->distnameinfo->dist=~/^(.*)-\w+/i;
+        my $module_name=$1 || "UNKNOWN";
+        $module_name=~s/-/::/g;
+        foreach (@modules_basedir) {
+            s/\.pm$//;
+            push(@modules,$module_name."::".$_);
+        }
     }
 
     if ($cpants->{metric}{dir_lib}) {
-	my @modules_path;
-	my $cnt=0;
-	foreach (@$files) {
-	    next unless m|^lib/(.*)\.pm$|;
-	    push(@module_files,$_);
-	    my $raw=$1;
-	    $raw=~s|/|::|g;
-	    push(@modules,$raw);
-	    $cnt++;
-	}
-	$cpants->{metric}{modules_in_lib}=$cnt;
+        my @modules_path;
+        my $cnt=0;
+        foreach (@$files) {
+            next unless m|^lib/(.*)\.pm$|;
+            push(@module_files,$_);
+            my $raw=$1;
+            $raw=~s|/|::|g;
+            push(@modules,$raw);
+            $cnt++;
+        }
+        $cpants->{metric}{modules_in_lib}=$cnt;
     }
 
     $cpants->{metric}{modules_list}=\@module_files;
@@ -66,31 +64,25 @@ sub analyse {
 ##################################################################
 
 
-__PACKAGE__->kwalitee_definitions
-  ([
-    {
-     name=>'proper_libs',
-     type=>'basic',
-     error=>q{There is more than one .pm file in the base dir, or the .pm files are not in directoy lib.},
-     code=>sub { 
-	 my $m=shift;
-	 return 1 if $m->{modules_in_basedir}==0 && $m->{dir_lib};
-	 return 1 if $m->{modules_in_basedir}==1;
-	 return 0;
-
-     },
+__PACKAGE__->kwalitee_definitions([{
+    name=>'proper_libs',
+    type=>'basic',
+    error=>q{There is more than one .pm file in the base dir, or the .pm files are not in directoy lib.},
+    code=>sub { 
+        my $m=shift;
+        return 1 if $m->{modules_in_basedir}==0 && $m->{dir_lib};
+        return 1 if $m->{modules_in_basedir}==1;
+        return 0;
     },
-
-   ]);
-
-
+}]);
 
 ##################################################################
 # DB
 ##################################################################
 
 sub sql_fields_dist {
-    return "   modules integer,
+    return 
+"   modules integer,
    modules_list text,
    modules_in_lib integer,
    modules_in_basedir integer,
@@ -100,13 +92,11 @@ sub sql_fields_dist {
 sub sql_other_tables {
     return ["
 create table modules_in_dist (
-  id integer primary key,
-  distid integer,
-  module text
+    id integer primary key,
+    dist text,
+    module text
 )",
-"CREATE INDEX mid_distid_idx on modules_in_dist (distid)
-",
-];
+    "CREATE INDEX mid_dist_idx on modules_in_dist (dist)\n"];
 }
 
 1;
